//
//  QHVCSharedConvertContainer.h
//  QHVCPlayerKit
//
//  Created by A Nie on 2020/4/28.
//  Copyright © 2020 qihoo 360. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <QHVCPlayerKit/QHVCPlayerEnum.h>

NS_ASSUME_NONNULL_BEGIN

@interface QHVCSharedConvertContainer : NSObject


/**
 下载器状态
 */
@property (nonatomic, assign, readonly) QHVCConvertStatus status;

/**
 @param url 源文件地址(同时支持网络和本地资源)
 @return 源文件音视频编码信息
 */
+ (NSDictionary *)getCodecInfoWithUrl:(NSString *)url key:(NSString *)key decryptType:(QHVCDecryptType)decryptType;

+ (instancetype)sharedInstance;

/**
@param url 源文件地址(同时支持网络和本地资源)
@param path 要保存的文件全路径（文件夹路径必须存在，包括文件名以及拓展名）
@param type 执行任务的类型
@param options 可选参数
@{
 @"width": NSNumber, // 输出视频width，默认取原视频width
 @"height": NSNumber, // 输出视频height，默认取原视频height
 @"bitrate":  NSNumber, // 输出视频bitrate，默认取原视频bitrate
 @"fps":  NSNumber, // 输出视频fps，默认取原视频fps
 @"layouts":
 "[{@"streamid": @(NSInteger), // 输入视频streamid
 @"x": @(NSInteger),  // 相对于输出视频 X 坐标
 @"y": @(NSInteger),  // 相对于输出视频 Y 坐标
 @"width" @(NSInteger), // 输入视频width
 @"height" @(NSInteger), // 输入视频height
 } ]", // 输出视频多路流布局
 @"key": NSString, // 解密密钥
 @"rotate": NSNumber // 输出视频旋转角度
 }
@param progressHandler 进度回调(1~100)100表示完成
@param completionHandler 结果回调
@return yes 参数合法 no 参数非法
*/
- (BOOL)startRemuxWithUrl:(NSString *)url savePath:(NSString *)path type:(QHVCTranscodeType)type options:(NSDictionary *_Nullable)options progress:(nullable void(^)(NSInteger progress))progressHandler completion:(nullable void (^)(BOOL success))completionHandler;


/**
停止下载（异步执行）
@param handler 停止结果回调
@return yes调用合法 no调用非法
*/
- (BOOL)stopRemuxWithHandler:(nullable void(^)(BOOL success))handler;

@end

NS_ASSUME_NONNULL_END
